#
# spec file for package python-Kajiki
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Kajiki
Version:        0.7.0
Release:        1.17
Summary:        Compiler for Genshi syntax outputting Python bytecode
License:        MIT
Group:          Development/Languages/Python
Url:            http://sourceforge.net/p/kajiki/home/
Source:         https://files.pythonhosted.org/packages/source/K/Kajiki/Kajiki-%{version}.tar.gz
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nine}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-nine
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
Kajiki compiles Genshi-like syntax to Python bytecode.

(Genshi is a Python library parsing, generating, and processing HTML, XML or
other textual content for output generation on the web.)

%prep
%setup -q -n Kajiki-%{version}

%build
%python_build

%install
%python_install

%check
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst LICENSE.rst
%{python_sitelib}/*

%changelog
* Thu Aug 24 2017 tbechtold@suse.com
- Add missing python-nine Requires
* Mon Jul 10 2017 jengelh@inai.de
- Remove storytelling from description.
* Thu Jun 29 2017 tbechtold@suse.com
- update to 0.7.0:
  * Text for i18n is now extracted ignoring the empty spaces surrounding the
    text itself. Empty text will always be treated as non translatable nodes
    for performance reasons.
  * ``extract_python`` option will now report syntax errors when extracting
    text for translation.
  * Added ``extract_python`` option to babel message extractor, this allows
    extracting gettext calls in ``${}`` expressions
  * Actually report 0.6 in kajiki/version.py
  * Expose ``strip_text`` option in loader
  * Fixed ``py:switch`` error message wrongly mentioning ``py:with``
  * Support for multiline ``${}`` expressions
  * Subsequent text nodes are now squashed into a single text node. This allows
    translating whole paragraphs instead of single sentences.
  * Allow code and function calls inside tag attributes
  * Added ``strip_text`` option to XMLTemplate and i18n collector to ensure
    leading and trailing spaces are stipped by text nodes (also leads to
    minified HTML)
  * Some HTML nodes that do not require being closed but is commonly considered
    best practice to close them are now emitted with ending tag (IE: <p>)
  * Generally improved code documentation to lower entry barrier for contributors
  * ``py:attrs`` will now emit the attribute name itself or will omit the attribute
    at all in case of ``bool`` values for 'checked', 'disabled', 'readonly',
    'multiple', 'selected', 'nohref', 'ismap', 'declare' and 'defer',
  * ``py:switch`` now correctly supports multiple ``py:case`` statements.
  * text inside ``<script>`` and ``<style>`` tags is no longer collected translation.
  * Syntax errors now report the line and the surrounding code when there is a
    markup or python syntax error.
  * As ``py:swtich`` discards all its content apart from ``py:case`` and
    ``py:else`` statements it will now correctly report an error when the
    statements has other content.
  * ``py:else`` will now correctly detect spurious content between itself and
    ``py:if`` as the two must be consequential.
  * Improved code documentation on core classes.
  * ``py:with`` statement now keeps order of variables, so that variables can
    depend from each other.
  * Babel is no longer a dependency unless you want to use the message extractor.
  * TranslatableTextNodes are now only generated for non-empty strings
  * ``py:with`` statement now accepts multiple variables separated by semicolon
  * Babel message extractor fixed on Python2
  * Fix crash on PyPy
  * CDATA sections created by the user are now properly preserved
  * ``cdata_scripts=False`` option in ``XMLTemplate`` allows disabling automatic
    CDATA for script and style tags.
  * Autoblocks experimental feature automatically creates blocks from specified
    tag names.
  * Also accept "$." without erroring out. In fact, accept anything.
  * Add integration plugin for TurboGears 1
  * Accept "$(" without erroring out. Easier to write jQuery stuff.
  * There was a showstopper regression in FileLoader. Fixes #1
  * Support Python versions 2.6, 2.7, 3.2, 3.3 in a single codebase
    using the *nine* library.
  * Support HTML entities as well as XML entities in input templates.
  * py:include fixed, can see global variables.
  * Genshi compatibility: support built-in functions:
    defined(), value_of() and Markup().
  * ``py:def``: Do not crash if a function has no content.
  * ``py:strip=''`` is the same as ``py:strip='True'``.
  * Correctness: escape HTML attribute values.
  * Correctness: Always close script tags, even in XML mode.
  * Add integration module for the Pyramid web framework.
  * Give the FileLoader a *path*, not just a base *directory*.
  * Documentation improvements, including the need to write CDATA sections.
  * Move from Sourceforge to Github.
  * Use Travis for continuous integration.
  * The whole codebase is formatted according to PEP8.
- convert to singlespec
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jan 17 2013 saschpe@suse.de
- Initial version
